@@ -1134,8 +1134,9 @@ bool Mapper::encode(Sink *sink, Status *status, SV *ref) const {
 
     bool tied = SvTIED_mg((SV *) hv, PERL_MAGIC_tied);
     bool ok = true;
-    int last_oneof = -1;
     WarnContext::Item &warn_cxt = warn_context->push_level(WarnContext::Message);
+    vector<bool> seen_oneof;
+    seen_oneof.resize(message_def->oneof_count());
     for (vector<Field>::const_iterator it = fields.begin(), en = fields.end(); it != en; ++it) {
         warn_cxt.field = &*it;
         HE *he = tied ? hv_fetch_ent_tied(aTHX_ hv, it->name, 0, it->name_hash) :
@@ -1150,10 +1151,9 @@ bool Mapper::encode(Sink *sink, Status *status, SV *ref) const {
             } else
                 continue;
         } else if (it->oneof_index != -1) {
-            if (it->oneof_index == last_oneof)
+            if (seen_oneof[it->oneof_index])
                 continue;
-            else
-                last_oneof = it->oneof_index;
+            seen_oneof[it->oneof_index] = true;
         }
 
         if (it->is_map)
@@ -2067,7 +2067,9 @@ void WarnContext::warn_with_context(pTHX_ SV *warning) const {
             sv_catpvf(cxt, "[%d].", it->index);
             break;
         case Hash:
-            sv_catpvf(cxt, "{%" SVf "}.", it->index);
+            sv_catpvs(cxt, "{");
+            sv_catpvn(cxt, it->key, it->keylen);
+            sv_catpvs(cxt, "}");
             break;
         case Message:
             sv_catpvf(cxt, "%" SVf ".", it->field->name);
